@@ -4,6 +4,17 @@ use Mojo::Base 'Ado::Control';
 sub authenticateduser { return $_[0]->render(text => 'hello authenticated ' . $_[0]->user->name) }
 sub mark_down         { return $_[0]->render(text => $_[0]->markdown('* some text')) }
 
+sub l10n {
+    $_[0]->debug('already set language:' . $_[0]->language);
+    return $_[0]->render(text => $_[0]->l('hello', $_[0]->user->name));
+}
+
+sub bgl10n {
+    $_[0]->language('bg');
+    $_[0]->debug('set language inside action:' . $_[0]->language);
+    return $_[0]->render(text => $_[0]->l('hello', $_[0]->user->name));
+}
+*index = \&l10n;
 1;
 
 =pod
@@ -17,8 +28,8 @@ Ado::Control::Test - a controller used for testing Ado.
 =head1 DESCRIPTION
 
 In this package we put actions which are used only for testing Ado functionality.
+Below is the list of defined actions.
 
-=head1 ACTIONS
 
 =head2 authenticateduser 
 
@@ -26,8 +37,19 @@ Used to test  the L<Ado::Plugin::Auth/authenticated> condition.
 
 =head2 mark_down
 
-Used to test  L<Ado::Plugin::MarkdownRenderer> C<markdown> helper
+Used to test theC<markdown> helper defined in L<Ado::Plugin::MarkdownRenderer/markdown>. 
 
+=head2 l10n
+
+Used to test the C<l> controller helper L<Ado::Plugin::I18n/l>.
+
+=head2 bgl10n
+
+Used to test the C<language> helper L<Ado::Plugin::I18n/language>.
+
+=head2 index
+
+Alias for C<l10n> action.
 
 =head1 AUTHOR
 
